function opts = ictkm_redraw_embedding(opts)
% -------------------------------------------------------------------------
% Redraws the Johnson-Lindenstrauss embedding. 
% -------------------------------------------------------------------------
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compressed Dictionary Learning Toolbox
% Copyright (C) Flavio Teixeira 2018
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, 
% Boston, MA  02110-1301, USA.    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% -------------------------------------------------------------------------
% Redraw JL transform
% -------------------------------------------------------------------------
if ~opts.noSketching
    opts.circulConvoVector = [];
    opts.circulConvoMatrix = [];
    
    if opts.useGPU
        opts.randSignCol = sign( randn(opts.d, 1, 'double', 'gpuArray') );
        opts.randSignMat = opts.randSignCol*ones(1, opts.K, ...
            'double', 'gpuArray');
        
        if strcmp(opts.FJLTtype,'PartialCirculant')
            circulConvoVector = fft( sign( randn(opts.d, 1) ) );
            opts.circulConvoVector = gpuArray(circulConvoVector);
            opts.circulConvoMatrix = ...
                spdiags(circulConvoVector, 0, opts.d, opts.d);
            opts.circulConvoMatrix = gpuArray(opts.circulConvoMatrix);
        end
    else
        opts.randSignCol = sign( randn(opts.d, 1) );
        opts.randSignMat = opts.randSignCol*ones(1, opts.K);
        
        if strcmp(opts.FJLTtype,'PartialCirculant')
            opts.circulConvoVector = fft( sign( randn(opts.d, 1) ) );
            opts.circulConvoMatrix = spdiags( opts.circulConvoVector, ...
                0, opts.d, opts.d);
        end
    end
end