function dinit = ictkm_dico_init(opts)
% -------------------------------------------------------------------------
% Computes the initialization dictionary for IcTKM. 
% -------------------------------------------------------------------------
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compressed Dictionary Learning Toolbox
% Copyright (C) Flavio Teixeira 2018
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, 
% Boston, MA  02110-1301, USA.    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if strcmp(opts.type,'Oracle')
    dinit = opts.odico;
else
    % Random initialization
    if opts.useGPU
        dinit = randn(opts.d, opts.K, 'double', 'gpuArray');
    else
        dinit = randn(opts.d, opts.K);
    end
    dinit = dinit * diag( 1./sqrt( sum(dinit.*dinit) ) );
    
    if strcmp(opts.type,'1:1_ratio') || strcmp(opts.type,'1:4_ratio')
        if isempty(opts.odico)
            error(['The original dictionary is needed for 1:1 ' ...
                'and 1:4 initializations']);
        end
        
        alpha=1;
        
        if strcmp(opts.type,'1:1_ratio')
            omega=1;
        elseif strcmp(opts.type,'1:4_ratio')
            omega=4;
        end
        
        for k=1:opts.K
            if opts.useGPU
                proj_compl = (eye(opts.d, 'gpuArray', 'double') - ...
                    opts.odico(:,k)*opts.odico(:,k)')*dinit(:,k);
            else
                proj_compl = (eye(opts.d) - ...
                    opts.odico(:,k)*opts.odico(:,k)')*dinit(:,k);
            end
            
            dinit(:,k) = alpha*opts.odico(:,k) + ...
                omega*proj_compl/norm(proj_compl);
        end
    end
    
    if opts.nonNegativeConstraint
        dinit = max(dinit, 0);
    end
end