function [dold, opts, results] = ictkm_init(opts, dinit, dataObj)
% -------------------------------------------------------------------------
% Initializes the IcTKM algorithm.
% -------------------------------------------------------------------------
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compressed Dictionary Learning Toolbox
% Copyright (C) Flavio Teixeira 2018
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, 
% Boston, MA  02110-1301, USA.    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if isempty(dinit)
    error('A initial guess for learning the dictionary is needed.');
elseif ( size(dinit,1) ~= opts.d && size(dinit,2) ~= opts.K )
    error('Initial dictionary guess has to be a dxK matrix');
end

if opts.useGPU
    if ~isa(dinit, 'gpuArray')
        % Store dictionary initialization in GPU
        dinit = gpuArray(dinit);
    end
end

dold = dinit;

if opts.noSketching
    opts.m = opts.d;
end

results=[];

results.avgTimePerIter = 0;
results.timePerIter = zeros(opts.numIter, 1);
results.runTime = 0;

results.rcorrIter = zeros(opts.K, opts.numIter);

if isa(dataObj, 'IcTKMSyntheticData')
    results.recovery_percent = zeros(opts.numIter, 1);
    results.approx_error = zeros(opts.numIter, 1);    
end