% -------------------------------------------------------------------------
% Driver function to start a scalability simulation.
% -------------------------------------------------------------------------
% Compile this as follows to run:
% =========================================================================
% mcc -mv -R ictkm_driver_compute_cluster_scalability_simulation.m
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compressed Dictionary Learning Toolbox
% Copyright (C) Flavio Teixeira 2018
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor,
% Boston, MA  02110-1301, USA.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

numITKMAlg=4;
numSparsityLevels = 2;
randomSeed = 1;
overcompletenessRatio = 3/2;
sampleSizeRatio = .5;
noiselessExactlySparseCoefficients = 0;
origDicoDiracDCT = 1;
origDicoHaarDCT = 0;
origDicoRandom = 1;
IcTKM_numIterations = 3;

ambientDimensionMultFactorVec = [2^1 2^2 2^3 2^4 (2^4+(2^5-2^4)/2) 2^5 ...
    (2^5+(2^6-2^5)/2) 2^6 (2^6+(2^7-2^6)/2) 2^7];

%% Iterate algorithm type
for iITKMAlg=1:numITKMAlg
    switch iITKMAlg
        case 1
            % ITKrM
            IcTKM_embedding_PartialFourier = 0;
            IcTKM_embedding_PartialDCT = 0;
            IcTKM_embedding_PartialCirculant = 0;
        case 2
            % IcTKM:DFT
            IcTKM_embedding_PartialFourier = 1;
            IcTKM_embedding_PartialDCT = 0;
            IcTKM_embedding_PartialCirculant = 0;            
        case 3
            %IcTKM:DCT
            IcTKM_embedding_PartialFourier = 0;
            IcTKM_embedding_PartialDCT = 1;
            IcTKM_embedding_PartialCirculant = 0;
        case 4
            %IcTKM:CGT
            IcTKM_embedding_PartialFourier = 0;
            IcTKM_embedding_PartialDCT = 0;
            IcTKM_embedding_PartialCirculant = 1;
    end
    
    %% Iterate ambient dimension
    for iDim=1:length(ambientDimensionMultFactorVec)
        %% Iterate sparsity level
        for iSparsityLevel=1:numSparsityLevels            
            intrinsicDimension = 1024;
            if iSparsityLevel==1
                sparsityLevel = 4;                                
                if IcTKM_embedding_PartialFourier 
                    % DFT uses more reduction values
                    dimReductionVec = [0.35 0.2 0.1];    
                else
                    dimReductionVec = [0.35 0.2];
                end                
            elseif iSparsityLevel==2
                sparsityLevel = ceil( sqrt(intrinsicDimension)/2 );
                if IcTKM_embedding_PartialFourier 
                    % DFT uses more reduction values
                    dimReductionVec = [0.4 0.3 0.25];
                else
                    dimReductionVec = [0.4 0.3];
                end                                                
            end
            
            ambientDimensionVec = ...
                    ceil(intrinsicDimension*ambientDimensionMultFactorVec);            
            ambientDimension = ambientDimensionVec(iDim);
            
            if IcTKM_embedding_PartialFourier || ...
                    IcTKM_embedding_PartialDCT || ...
                    IcTKM_embedding_PartialCirculant
                %% Iterate dimension reduction
                for iDimReduction=1:length(dimReductionVec)
                    dimReduction = dimReductionVec(iDimReduction);
                    
                    % IcTKM
                    ictkm_scalability_simulation(...
                        randomSeed, ...
                        ambientDimension, ...
                        intrinsicDimension, ...
                        overcompletenessRatio, ...
                        sampleSizeRatio, ...
                        dimReduction, ...
                        sparsityLevel, ...
                        noiselessExactlySparseCoefficients, ...
                        origDicoDiracDCT, ....
                        origDicoHaarDCT, ...
                        origDicoRandom, ...
                        IcTKM_numIterations,...
                        IcTKM_embedding_PartialFourier, ...
                        IcTKM_embedding_PartialDCT, ...
                        IcTKM_embedding_PartialCirculant);
                end
            else
                dimReduction = 1;
                
                %ITKrm
                ictkm_scalability_simulation(...
                    randomSeed, ...
                    ambientDimension, ...
                    intrinsicDimension, ...
                    overcompletenessRatio, ...
                    sampleSizeRatio, ...
                    dimReduction, ...
                    sparsityLevel, ...
                    noiselessExactlySparseCoefficients, ...
                    origDicoDiracDCT, ....
                    origDicoHaarDCT, ...
                    origDicoRandom, ...
                    IcTKM_numIterations,...
                    IcTKM_embedding_PartialFourier, ...
                    IcTKM_embedding_PartialDCT, ...
                    IcTKM_embedding_PartialCirculant);
            end
        end
    end
end