function ictkm_driver_compute_cluster_synthetic_simulation(...
    randomSeed, ...
    ambientDimension, ...
    intrinsicDimension, ...
    sampleSizeRatio, ...
    compressionRatio, ...
    useLowerSparsityLevel, ...
    IcTKM_numIterations,...
    IcTKM_embedding_PartialFourier, ...
    IcTKM_embedding_PartialDCT, ...
    IcTKM_embedding_PartialCirculant,...
    useScratchSpace)
% -------------------------------------------------------------------------
% Driver function to start a synthetic data simulation on University of 
% Innsbruck's compute cluster.
% -------------------------------------------------------------------------
% Compile this as follows to run on the cluster:
% =========================================================================
% mcc -mv -R -nojvm -R -singleCompThread ictkm_driver_compute_cluster_synthetic_simulation.m
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compressed Dictionary Learning Toolbox
% Copyright (C) Flavio Teixeira 2018
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor,
% Boston, MA  02110-1301, USA.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% =========================================================================
% Deployed application have to treat input parameters differently
% =========================================================================
if isdeployed
    randomSeed = str2double(randomSeed);
    ambientDimension = str2double(ambientDimension);
    intrinsicDimension = str2double(intrinsicDimension);
    sampleSizeRatio = str2double(sampleSizeRatio);
    compressionRatio = str2double(compressionRatio);
    useLowerSparsityLevel = str2double(useLowerSparsityLevel);
    IcTKM_numIterations = str2double(IcTKM_numIterations);
    IcTKM_embedding_PartialFourier = ...
        str2double(IcTKM_embedding_PartialFourier);
    IcTKM_embedding_PartialDCT = ...
        str2double(IcTKM_embedding_PartialDCT);
    IcTKM_embedding_PartialCirculant = ...
        str2double(IcTKM_embedding_PartialCirculant);
    useScratchSpace = str2double(useScratchSpace);
end

% =========================================================================
% Generate filename based on simulation parameters
% =========================================================================

formatOut = 'mm_dd_yyyy_HH_MM_SS_FFF';
date_str = datestr(now,formatOut);

signal_type_str = 'signalType_noisy';

dico_type_str = 'initDictionary_random';

if useLowerSparsityLevel
    sparsity_level_str = 'low';
else
    sparsity_level_str = 'high';
end

resultsFilename = ...
    strsplit(mfilename('fullpath'),['compute_cluster/' mfilename]);
resultsFilename = resultsFilename{1};

if (~IcTKM_embedding_PartialFourier && ...
        ~IcTKM_embedding_PartialDCT && ...
        ~IcTKM_embedding_PartialCirculant)
    
    resultsFilename =  ...
        [resultsFilename '/results/ITKM_synthetic_simulation_d_' ...
        num2str(ambientDimension) ...
        '_d_intrinsic_' num2str(intrinsicDimension) ...
        '_sampleSizeRatio_' num2str(sampleSizeRatio) ...
        '_sparsityLevel_' sparsity_level_str ...
        '_' signal_type_str '_' dico_type_str '_' date_str '.mat'];
else
    % =====================================================================
    % Configure the Johnson-Lindenstrauss embedding
    % =====================================================================
    FJLT_type_str = [];
    if IcTKM_embedding_PartialFourier
        FJLT_type_str = 'PartialFourier_embedding';
    elseif IcTKM_embedding_PartialDCT
        FJLT_type_str = 'PartialDCT_embedding';
    elseif IcTKM_embedding_PartialCirculant
        FJLT_type_str = 'PartialCirculant_embedding';
    end
    
    resultsFilename = ...
        [resultsFilename '/results/IcTKM_synthetic_simulation_d_' ...
        num2str(ambientDimension) ...
        '_d_intrinsic_' num2str(intrinsicDimension) ...
        '_sampleSizeRatio_' num2str(sampleSizeRatio) ...
        '_compressRatio_' num2str(compressionRatio) ...
        '_sparsityLevel_' sparsity_level_str ...
        '_' FJLT_type_str '_' signal_type_str '_' dico_type_str ...
        '_' date_str '.mat'];
end

if useScratchSpace
    resultsFilename = strcat('/scratch/c7021060/', resultsFilename);
end

verboseAlgorithm = 0;

% This is not supported in the compute cluster
useParallelization = 0;
useGpuAcceleration = 0;

% =========================================================================
% Run the simulation
% =========================================================================
ictkm_synthetic_simulation(...
    randomSeed, ...
    ambientDimension, ...
    intrinsicDimension, ...
    sampleSizeRatio, ...
    compressionRatio, ...
    useLowerSparsityLevel, ...
    IcTKM_numIterations,...
    IcTKM_embedding_PartialFourier, ...
    IcTKM_embedding_PartialDCT, ...
    IcTKM_embedding_PartialCirculant,...
    verboseAlgorithm,...
    useParallelization,...
    useGpuAcceleration,...
    resultsFilename);
