function percent_recov_cell = ...
    ictkm_compute_cluster_gather_mat_files(file_type)
% -------------------------------------------------------------------------
% Put together all the simulation results in the percent_recov_cell
% cell array.
% -------------------------------------------------------------------------
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compressed Dictionary Learning Toolbox
% Copyright (C) Flavio Teixeira 2018
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor,
% Boston, MA  02110-1301, USA.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if file_type == 1
    % =====================================================================
    % Import .mat files from try_sample_size folder
    % =====================================================================
    rec_threshold = 0.99;
    
    num_sparsity_levels = 2;
    compression_ratio_vector = [0 2.5 5 10 20 50];
    num_compression_ratios = length(compression_ratio_vector);
    
    %sample_size_ratio_vector = [1 5 10 25 50 75 100];
    sample_size_ratio_vector = [1 5 10 25 50];
    
    num_sample_size_ratios = length(sample_size_ratio_vector);
    
    %num_ambient_dim = 4;
    num_ambient_dim = 3;
    
    percent_recov_cell = zeros(num_sparsity_levels, num_compression_ratios, ...
        num_sample_size_ratios, num_ambient_dim);
    
    signal_type_str = 'signalType_noisy';
    init_dico_str = 'initDictionary_oracle';
    
    for i_sparsity=1:num_sparsity_levels
        sparsity_str = 'sparsityLevel_';
        if i_sparsity == 1
            sparsity_str = strcat(sparsity_str, 'low');
            ambient_dim_vector = [1024 2048 4096 8192];
        elseif i_sparsity == 2
            sparsity_str = strcat(sparsity_str, 'high');
            ambient_dim_vector = [512 1024 2048 4096];
        end
        
        for i_dim=1:num_ambient_dim
            K = 3*ambient_dim_vector(i_dim)/2;
            rcorr_ictkm = zeros(K, num_compression_ratios);
            
            for i_sample_size_ratio=1:num_sample_size_ratios
                sample_size_str = strcat( 'sampleSizeRatio_', ...
                    num2str( sample_size_ratio_vector(i_sample_size_ratio) ) );
                jl_embedding_str = 'PartialFourier_embedding';
                
                for i_compression_ratio=1:num_compression_ratios
                    search_str = strcat(pwd, '/compute_cluster/mat_files/try_sample_size/');
                    
                    if (compression_ratio_vector(i_compression_ratio) ~= 0)
                        compression_ratio_str = strcat('compressRatio_', ...
                            num2str( compression_ratio_vector(i_compression_ratio) ) );
                        search_str = strcat(search_str, 'IcTKM_synthetic_simulation', '_');
                    else
                        search_str = strcat(search_str, 'ITKM_synthetic_simulation', '_');
                    end
                    
                    search_str = strcat(search_str, ...
                        ['d_' num2str( ambient_dim_vector(i_dim) )], '_');
                    search_str = strcat(search_str, ...
                        'd_intrinsic_', num2str( ambient_dim_vector(i_dim) ), '_');
                    search_str = strcat(search_str, ...
                        sample_size_str, '_');
                    
                    if (compression_ratio_vector(i_compression_ratio) ~= 0)
                        search_str = strcat(search_str, compression_ratio_str, '_');
                    end
                    
                    search_str = strcat(search_str, sparsity_str, '_');
                    
                    if (compression_ratio_vector(i_compression_ratio) ~= 0)
                        search_str = strcat(search_str, jl_embedding_str, '_');
                    end
                    
                    search_str = strcat(search_str, signal_type_str, '_');
                    search_str = strcat(search_str, init_dico_str, '_*');
                    
                    list = ls(search_str);
                    list = strsplit(list);
                    
                    filename = strjoin( list(:) );
                    if ~isempty(filename)
                        S = load( strcat( '', strjoin( list(:) ) ) );
                        rcorr_ictkm(:, i_compression_ratio) = ...
                            min(S.rcorr_per_iter, [], 2);
                        
                        rec_count = ...
                            find( rcorr_ictkm(:, i_compression_ratio) > rec_threshold );
                        
                        percent_recov_cell(i_sparsity, i_compression_ratio, ...
                            i_sample_size_ratio, i_dim) = (length(rec_count)/K)*100;
                    end
                end
            end
        end
    end
elseif file_type == 2
    % =====================================================================
    % Import .mat files from ? folder
    % =====================================================================
end

end
