function ictkm_scalability_simulation(...
                                        randomSeed, ...
                                        ambientDimension, ...
                                        intrinsicDimension, ...
                                        overcompletenessRatio, ...
                                        sampleSizeRatio, ...
                                        dimReduction, ...
                                        sparsityLevel, ...
                                        noiselessExactlySparseCoefficients, ...
                                        origDicoDiracDCT, ....
                                        origDicoHaarDCT, ...
                                        origDicoRandom, ...
                                        IcTKM_numIterations,...
                                        IcTKM_embedding_PartialFourier, ...
                                        IcTKM_embedding_PartialDCT, ...
                                        IcTKM_embedding_PartialCirculant...
                                    )
% -------------------------------------------------------------------------
% Runs a dictionary learning scalability simulation with IcTKM. 
% -------------------------------------------------------------------------
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compressed Dictionary Learning Toolbox
% Copyright (C) Flavio Teixeira 2018
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, 
% Boston, MA  02110-1301, USA.    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%==========================================================================
% Display parameters
%==========================================================================
disp('ictkm_scalability_simulation parameters')
disp([sprintf('\t') 'ambientDimension: ' num2str(ambientDimension) ]);
disp([sprintf('\t') 'intrinsicDimension: ' num2str(intrinsicDimension) ]);
disp([sprintf('\t') 'sampleSizeRatio: ' num2str(sampleSizeRatio) ]);
disp([sprintf('\t') 'dimReduction: ' num2str(dimReduction) ]);
disp([sprintf('\t') 'sparsityLevel: ' num2str(sparsityLevel) ]);
disp([sprintf('\t') 'noiselessExactlySparseCoefficients: ' ...
    num2str(noiselessExactlySparseCoefficients) ]);
disp([sprintf('\t') 'origDicoDiracDCT: ' num2str(origDicoDiracDCT) ]);
disp([sprintf('\t') 'origDicoHaarDCT: ' num2str(origDicoHaarDCT) ]);
disp([sprintf('\t') 'origDicoRandom: ' num2str(origDicoRandom) ]);
disp([sprintf('\t') 'IcTKM_numIterations: ' num2str(IcTKM_numIterations) ]);
disp([sprintf('\t') 'IcTKM_embedding_PartialFourier: ' ...
    num2str(IcTKM_embedding_PartialFourier) ]);
disp([sprintf('\t') 'IcTKM_embedding_PartialDCT: ' ...
    num2str(IcTKM_embedding_PartialDCT) ]);
disp([sprintf('\t') 'IcTKM_embedding_PartialCirculant: ' ...
    num2str(IcTKM_embedding_PartialCirculant) ]);

%==========================================================================
% Initialize IcTKM simulation structure
%==========================================================================
optsIcTKMSimulation=[];

% Set IcTKM misc configurations
optsIcTKMSimulation.IcTKM_numIter = IcTKM_numIterations;
optsIcTKMSimulation.IcTKM_verbose = 0;
optsIcTKMSimulation.IcTKMHaltOnPerfectRecovery = 0;
optsIcTKMSimulation.randomSeed = randomSeed;

% Sets the IcTKM Run mode
optsIcTKMSimulation.IcTKM_runMode_sequential = 1;

%optsIcTKMSimulation.IcTKM_runMode_parallel = 1;
%optsIcTKMSimulation.IcTKM_runMode_parallel_boost_workers = 0;

%optsIcTKMSimulation.IcTKM_runMode_useGPU = 1;

% Create initialization for the IcTKM
optsIcTKMSimulation.DicoInit_random = 1;

% Define the problem size
optsIcTKMSimulation.ambientDimension = ambientDimension;
optsIcTKMSimulation.intrinsicDimension = intrinsicDimension;
optsIcTKMSimulation.overcompletenessRatio = overcompletenessRatio;

% Create data set for learning the dictionary
optsIcTKMSimulation.SampleSizeRatio = sampleSizeRatio;
optsIcTKMSimulation.DataModeSynthetic = 1;

% Chooses the dictionary for generating the data
optsIcTKMSimulation.SyntheticData_origDicoDiracDCT = origDicoDiracDCT;
optsIcTKMSimulation.SyntheticData_origDicoHaarDCT = origDicoHaarDCT;
optsIcTKMSimulation.SyntheticData_origDicoRandom = origDicoRandom;

%optsIcTKMSimulation.SyntheticData_S = 4;
% ceil( sqrt(optsIcTKMSimulation.intrinsicDimension)/2 );
optsIcTKMSimulation.SyntheticData_S = sparsityLevel;

optsIcTKMSimulation.SyntheticData_dynamicRange = 4;
if noiselessExactlySparseCoefficients
    signal_type_str = 'noiseless';
    optsIcTKMSimulation.SyntheticData_fixedCoeffDecay = 1;
    optsIcTKMSimulation.SyntheticData_flatCoeff = 1;
    optsIcTKMSimulation.SyntheticData_noiseLevel = 0;
else
    signal_type_str = 'noisy';
    optsIcTKMSimulation.SyntheticData_fixedCoeffDecay = 0;
    optsIcTKMSimulation.SyntheticData_flatCoeff = 0;
    optsIcTKMSimulation.SyntheticData_noiseLevel = ...
        1/( 2*sqrt(optsIcTKMSimulation.ambientDimension) );
end
optsIcTKMSimulation.SyntheticData_recThres = 0.95;  % Threshold for
                                                    % perfect recovery.

formatOut = 'mm_dd_yyyy_HH_MM_SS_FFF';
date_str = datestr(now,formatOut);

dico_type_str = [];
if optsIcTKMSimulation.SyntheticData_origDicoDiracDCT
    dico_type_str = 'Dictionary_Dirac_DCT';
elseif optsIcTKMSimulation.SyntheticData_origDicoHaarDCT
    dico_type_str = 'Dictionary_Haar_DCT';
elseif optsIcTKMSimulation.SyntheticData_origDicoRandom
    dico_type_str = 'Dictionary_Random';
end

resultsFilename = ...
    strsplit(mfilename('fullpath'),mfilename);
resultsFilename = resultsFilename{1};

percent_recovered_atoms_vec = []; %#ok<NASGU>
rcorr = [];
if (~IcTKM_embedding_PartialFourier && ...
        ~IcTKM_embedding_PartialDCT && ...
        ~IcTKM_embedding_PartialCirculant)
    %======================================================================
    % Run the ITKM simulation and collect results
    %======================================================================
    optsIcTKMSimulation.IcTKM_embedding_disabled = 1;% Disable JL embedding
    
    simResults = ictkm_simulation(optsIcTKMSimulation);
    percent_recovered_atoms_vec = simResults.recovery_percent; %#ok<NASGU>
    rcorr = [simResults.rcorr; rcorr];  %#ok<NASGU>
    avg_recovery_time = simResults.avgTimePerIter; %#ok<NASGU>
    
    results_filename = ...
        [resultsFilename '/results/ITKM_embedding_simulation_d_', ...
        num2str(ambientDimension), '_d_intrinsic_', ...
        num2str(intrinsicDimension), '_sparsityLevel_' ...
        num2str(sparsityLevel) '_' signal_type_str '_' dico_type_str ...
        '_' date_str '.mat'];
    
    save(results_filename , ...
        'percent_recovered_atoms_vec', ...
        'avg_recovery_time', ...
        'rcorr');
else
    %======================================================================
    % Configure the Johnson-Lindenstrauss embedding
    %======================================================================
    optsIcTKMSimulation.IcTKM_embedding_disabled = 0;
    optsIcTKMSimulation.IcTKM_embedding_PartialFourier = ...
        IcTKM_embedding_PartialFourier;
    optsIcTKMSimulation.IcTKM_embedding_PartialDCT = ...
        IcTKM_embedding_PartialDCT;
    optsIcTKMSimulation.IcTKM_embedding_PartialCirculant=...
        IcTKM_embedding_PartialCirculant;
    optsIcTKMSimulation.IcTKM_embedding_dimension = ...
        ceil(dimReduction*optsIcTKMSimulation.ambientDimension);
    
    %======================================================================
    % Run the IcTKM simulation
    %======================================================================
    simResults = ictkm_simulation(optsIcTKMSimulation);
    
    %======================================================================
    % Collect simulation results and save to file
    %======================================================================
    percent_recovered_atoms_vec = simResults.recovery_percent; %#ok<NASGU>
    rcorr = [simResults.rcorr; rcorr];  %#ok<NASGU>
    avg_recovery_time = simResults.avgTimePerIter; %#ok<NASGU>
    
    FJLT_type_str = [];
    if optsIcTKMSimulation.IcTKM_embedding_PartialFourier
        FJLT_type_str = 'PartialFourier_embedding';
    elseif optsIcTKMSimulation.IcTKM_embedding_PartialDCT
        FJLT_type_str = 'PartialDCT_embedding';
    elseif optsIcTKMSimulation.IcTKM_embedding_PartialCirculant
        FJLT_type_str = 'PartialCirculant_Gaussian';
    end
    
    results_filename = ...
        [resultsFilename '/results/IcTKM_embedding_simulation_d_' ...
        num2str(ambientDimension) '_d_intrinsic_' ...
        num2str(intrinsicDimension) '_d_reduction_' ...
        num2str(dimReduction) '_sparsityLevel_' ...
        num2str(sparsityLevel) '_' FJLT_type_str '_' ...
        signal_type_str '_' dico_type_str '_' date_str '.mat'];
    
    save(results_filename , ...
        'percent_recovered_atoms_vec', ...
        'avg_recovery_time', ...
        'rcorr');     
end

