function ictkm_audio_simulation_show_results()
% -------------------------------------------------------------------------
% Show results for the dictionary learning simulations with audio data.
% -------------------------------------------------------------------------
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compressed Dictionary Learning Toolbox
% Copyright (C) Flavio Teixeira 2018
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor,
% Boston, MA  02110-1301, USA.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

saveFig2Tikz = 0;
flipCMap = 1;

audioFileIdx = 9;
audio_array = ...
    [{'classical_brass_band.wav'}, {'classical_orchestral.wav'},...
    {'classical_piano.wav'}, {'flamenco.wav'}, {'funk.wav'},...
    {'heavy_metal.wav'}, {'jazz.wav'}, {'techno.wav'} {'folk_japanese.wav'}];

maxFreq_hz = 4000;
plot_dictionary_spectra(audioFileIdx, audio_array, maxFreq_hz, ...
    saveFig2Tikz, flipCMap);


%atom_number_array = [15 183];
%max_frequency_khz = 6;
%plot_atom_spectrogram(audioFileIdx, audio_array, atom_number_array, ...
%    max_frequency_khz, saveFig2Tikz, flipCMap);

    function plot_dictionary_spectra(audioFileIndex, audio_genre_array, ...
            maxFrequency ,saveFigToTikz, flipColorMap)
        audioGenre = audio_genre_array{audioFileIndex};
        
        for i_sparsity=1:2
            if i_sparsity == 1
                sparsity_str = '_S_4';
                continue;
            elseif i_sparsity == 2
                sparsity_str = '_S_10';
            end
            
            for i_frame_length=1:2
                if i_frame_length == 1
                    frame_length_str = '_frameLeng_0.25';
                elseif i_frame_length == 2
                    frame_length_str = '_frameLeng_1';
                    continue;
                end
                
                for i_atoms=1:2
                    if i_atoms == 1
                        atoms_str = '_K_64';
                    elseif i_atoms == 2
                        atoms_str = '_K_256';
                    end
                    
                    filename = strcat('results/IcTKM_audio_simulation_audioFile_', ...
                        audioGenre);
                    filename = strcat(filename, atoms_str);
                    filename = strcat(filename, sparsity_str);
                    filename = strcat(filename, frame_length_str);
                    filename = strcat(filename, ...
                        '_frameOff_0.0125_compressRatio_5_numFramesPerBlock_1_FJLTType_PartialDCT_embedding_numIter_200.mat');
                    
                    load(filename);
                    
                    d = size(dico, 1); %#ok<NODEF>
                    K = size(dico,2);
                    fs = 44100;
                    
                    d_2 = ceil(d/2);
                    spectr = zeros(d_2,K);
                    max_val = zeros(K, 1);
                    for i=1:K
                        X_mags = abs(fft(dico(:,i)));
                        
                        bin_vals = [0 : d-1];
                        fax_Hz = bin_vals*fs/d;
                        
                        spectr(:,i) = 20*log10(X_mags(1:d_2));
                        
                        [~, indx] = max( spectr(:,i) );
                        max_val(i) = indx;
                    end
                    
                    I = find(fax_Hz > maxFrequency);
                    
                    index_freq = I(1);
                    
                    [~,I] = sort(max_val);
                    
                    fax_Hz_single_sided = fax_Hz(1:d_2);
                    f0_vector = unique( sort( fax_Hz_single_sided(max_val) ) );
                    
                    display([audioGenre '. Number of unique notes identified is: ' ...
                        num2str( length(f0_vector) ) ' for K=' num2str(K) ...
                        ' and the frequency range is [' num2str( min(f0_vector) ) ...
                        ', ' num2str( max(f0_vector) ) ']']);
                    
                    
                    %                     figure;
                    %                     stem(f0_vector);
                    
                    figure;
                    imagesc((spectr(1:index_freq,I)));
                    
                    yticklabels = 0:ceil(fs/100):fs/2;
                    yticks = linspace(1, size(spectr, 1), numel(yticklabels));
                    set(gca, 'YTick', yticks, 'YTickLabel', yticklabels);
                    
                    set(gca,'YDir','normal');
                    
                    xlabel('Atom number');
                    ylabel('Frequency (kHz)');
                    
                    colormap gray;
                    % get the matrix containing that colormap:
                    cmap = colormap;
                    if flipColorMap
                        % flip the matrix:
                        cmap = flipud(cmap);
                    end
                    % apply the new inverted colormap:
                    colormap(cmap);
                    h_colorbar = colorbar;
                    title(h_colorbar, 'dB');
                    
                    if i_atoms == 1
                        title([audioGenre ' with K=64'], 'interpreter', 'none');
                    elseif i_atoms == 2
                        title([audioGenre ' with K=256'], 'interpreter', 'none');
                    end
                    
                    if saveFigToTikz
                        tikz_filename = 'figs/tikz/dictionary_spectra_';
                        tikz_filename = strcat(tikz_filename, audioGenre);
                        tikz_filename = strcat(tikz_filename, atoms_str);
                        tikz_filename = strcat(tikz_filename, sparsity_str);
                        tikz_filename = strcat(tikz_filename, frame_length_str);
                        tikz_filename = strcat(tikz_filename, '.tikz');
                        
                        matlab2tikz(tikz_filename, ...
                            'height','\figureheight',...
                            'width','\figurewidth', ...
                            'extraaxisoptions','legend style={font=\tiny}');
                    end
                end
            end
        end
    end

    function plot_atom_spectrogram(audioFileIndex, audio_genre_array, ...
            atom_num_array, max_freq, saveFigToTikz, flipColorMap)
        
        audioGenre = audio_genre_array{audioFileIndex};
        
        num_atoms = length(atom_num_array);
        
        for i_atom=1:num_atoms
            atom_number = atom_num_array(i_atom);
            
            for i_sparsity=1:2
                if i_sparsity == 1
                    sparsity_str = '_S_4';
                    continue;
                elseif i_sparsity == 2
                    sparsity_str = '_S_10';
                end
                
                f = figure;
                p = uipanel('Parent',f,'BorderType','none');
                %                 p.Title = ['atom number = ' num2str(atom_number)];
                %                 p.TitlePosition = 'centertop';
                %                 p.FontSize = 12;
                %                 p.FontWeight = 'bold';
                
                for i_frame_length=1:2
                    
                    if i_frame_length == 1
                        subplot(1, 16, 1:4, 'Parent', p)
                    elseif i_frame_length == 2
                        subplot(1, 16, 6:16, 'Parent', p)
                    end
                    
                    
                    if i_frame_length == 1
                        frame_length_str = '_frameLeng_0.25';
                    elseif i_frame_length == 2
                        frame_length_str = '_frameLeng_1';
                    end
                    
                    
                    for i_atoms=1:2
                        if i_atoms == 1
                            atoms_str = '_K_64';
                            continue;
                        elseif i_atoms == 2
                            atoms_str = '_K_256';
                        end
                        
                        filename = strcat('results/IcTKM_audio_simulation_audioFile_', audioGenre);
                        filename = strcat(filename, atoms_str);
                        filename = strcat(filename, sparsity_str);
                        filename = strcat(filename, frame_length_str);
                        filename = strcat(filename, ...
                            '_frameOff_0.0125_compressRatio_5_numFramesPerBlock_1_FJLTType_PartialDCT_embedding_numIter_200.mat');
                        
                        load(filename);
                        
                        % ========================================
                        % Sort dictionary by fundamental frequency
                        % ========================================
                        
                        d = size(dico, 1);
                        K = size(dico,2);
                        
                        d_2 = ceil(d/2);
                        spectr = zeros(d_2,K);
                        max_val = zeros(K, 1);
                        for i=1:K
                            X_mags = abs(fft(dico(:,i)));
                            
                            %bin_vals = [0 : d-1];
                            %fax_Hz = bin_vals*fs/d;
                            
                            spectr(:,i) = 20*log10(X_mags(1:d_2));
                            
                            [~, indx] = max( spectr(:,i) );
                            max_val(i) = indx;
                        end
                        
                        [~,I] = sort(max_val);
                        % =====================================================
                        dico = dico(:,I);
                        
                        x = dico(:,atom_number);
                        
                        
                        fs = 44100;
                        window_size = ceil(0.02*fs);
                        noverlap = ceil(window_size/2);
                        nfft = fs/4;
                        
                        spectrogram(x,window_size, noverlap, nfft, fs, ...
                            'yaxis', 'power');
                        
                        ylim([0, max_freq]);
                        
                        if i_frame_length == 1
                            pbaspect([.25 1 1]);
                            colorbar off;
                            set(gca,'XLabel',[])
                        else
                            set(gca,'YLabel',[]);
                            set(gca,'YTick',[]);
                            
                            xlabh = get(gca,'XLabel');
                            
                            %pbaspect([1 1 1]);
                            colormap gray;
                            % get the matrix containing that colormap:
                            cmap = colormap;
                            
                            if flipColorMap
                                % flip the matrix:
                                cmap = flipud(cmap);
                            end
                            
                            % apply the new inverted colormap:
                            colormap(cmap);
                            h_colorbar = colorbar;
                            title(h_colorbar, 'dB');
                        end
                        
                        %                         title(['d=' num2str(length(x))]);
                        
                        if saveFigToTikz
                            tikz_filename = 'figs/tikz/spectrogram_';
                            tikz_filename = strcat(tikz_filename, audioGenre);
                            tikz_filename = strcat(tikz_filename, atoms_str);
                            tikz_filename = strcat(tikz_filename, sparsity_str);
                            tikz_filename = strcat(tikz_filename, ...
                                ['_atom_num_' num2str(atom_number)]);
                            tikz_filename = strcat(tikz_filename, '.tikz');
                            
                            matlab2tikz(tikz_filename, ...
                                'height','\figureheight',...
                                'width','\figurewidth', ...
                                'extraaxisoptions','legend style={font=\tiny}');
                            
                        end
                    end
                end
            end
        end
    end
end