function ictkm_synthetic_simulation_show_results()
% -------------------------------------------------------------------------
% Show results for the dictionary learning simulations with synthetic data.
% -------------------------------------------------------------------------
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compressed Dictionary Learning Toolbox
% Copyright (C) Flavio Teixeira 2018
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor,
% Boston, MA  02110-1301, USA.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

saveFig2Tikz = 1;

marker_1 = 'x';
marker_2 = 'o';
marker_3 = 's';
marker_4 = 'd';

line_style_1 = '-.';
line_style_2 = ':';
line_style_3 = '--';
line_style_4 = '-';


%% First run
dim_vector = [2^8 2^9 2^10];
simulation_num = 1;
recovery_threshold_percent = 95.5;
show_scalability_with_dimension(recovery_threshold_percent, simulation_num, saveFig2Tikz)

% show_compression_ratio(dim_vector, recovery_threshold_percent, simulation_num);
show_convergence_speed_unrecovered_atoms(dim_vector, ...
    recovery_threshold_percent, simulation_num, saveFig2Tikz, 1);
show_convergence_speed_unrecovered_atoms(dim_vector, ...
    recovery_threshold_percent, simulation_num, saveFig2Tikz, 2);


%% Second run
% dim_vector = [2^9 2^10 2^11];
% simulation_num = 2;
% recovery_threshold_percent = 90;
% show_scalability_with_dimension(recovery_threshold_percent, simulation_num, saveFig2Tikz)

% show_compression_ratio(dim_vector, recovery_threshold_percent, simulation_num);
% show_convergence_speed_unrecovered_atoms(dim_vector, ...
%     recovery_threshold_percent, simulation_num, saveFig2Tikz, 1);
% show_convergence_speed_unrecovered_atoms(dim_vector, ...
%     recovery_threshold_percent, simulation_num, saveFig2Tikz, 2);

    function show_compression_ratio(d_vector, recovery_threshold, simulation_num)
        num_embedding_types=3;
        
        %% Iterate over dictionary types
        for i_dico_type=1:2
            dico_type_str = [];
            if i_dico_type == 1
                dico_type_str = 'Random'; %#ok<NASGU>
                continue;
            elseif i_dico_type == 2
                dico_type_str = 'Dirac_DCT';
                %continue;
            end
            %% Iterate over signal types
            for i_signal_type=1:2
                signal_type_str = [];
                if i_signal_type == 1
                    signal_type_str = 'noiseless'; %#ok<NASGU>
                    continue;
                elseif i_signal_type == 2
                    signal_type_str = 'noisy';
                end
                
                %% Iterate over dimension vector
                for i_embedding_type=1:num_embedding_types
                    for i_dim=1:length(d_vector)
                        switch i_embedding_type
                            case 1
                                embedding_type_str = 'PartialFourier';
                            case 2
                                embedding_type_str = 'PartialDCT';
                            case 3
                                embedding_type_str = ...
                                    'PartialCirculant_Gaussian';
                        end
                        
                        [dim_reduction_vector, ~, ...
                            percent_recovered_atoms_mat, ~, ~] = ...
                            ictkm_simulation_gather_results(...
                            d_vector(i_dim), dico_type_str, ...
                            signal_type_str, embedding_type_str, ...
                            simulation_num);
                        
                        [I,~] = ind2sub( size(percent_recovered_atoms_mat), ...
                            find(percent_recovered_atoms_mat > recovery_threshold) );
                        
                        display(['simulation num: ' num2str(simulation_num) ...
                            ', dimension: ' num2str(d_vector(i_dim)) ...
                            ', embedding type: ' embedding_type_str ...
                            ', max compression ratio: ' ...
                            num2str(1/dim_reduction_vector(max(I))) ':1']);
                    end
                end
            end
        end
    end

    function show_scalability_with_dimension(recovery_threshold, ...
            simulation_num, saveFigToTikz)
        num_embedding_types=4;
        
        d_intrinsic_dimension = 1024;
        
        %% Iterate over dictionary types
        for i_dico_type=1:2
            dico_type_str = [];
            if i_dico_type == 1
                dico_type_str = 'Random'; %#ok<NASGU>
                continue;
            elseif i_dico_type == 2
                dico_type_str = 'Dirac_DCT';
            end
            
            %% Iterate over signal types
            for i_signal_type=1:2
                signal_type_str = [];
                if i_signal_type == 1
                    signal_type_str = 'noiseless'; %#ok<NASGU>
                    continue;
                elseif i_signal_type == 2
                    signal_type_str = 'noisy';
                end
                
                figure;
                for i_embedding_type=1:num_embedding_types
                    switch i_embedding_type
                        case 1
                            embedding_type_str = 'PartialFourier';
                            legend_string = 'IcTKM-DFT, ';
                            cmap = colormap(summer);
                        case 2
                            embedding_type_str = 'PartialDCT';
                            legend_string = 'IcTKM-DCT, ';
                            cmap = colormap(winter);
                        case 3
                            embedding_type_str = ...
                                'PartialCirculant_Gaussian';
                            legend_string = 'IcTKM-CRT, ';
                            cmap = colormap(autumn);
                        case 4
                            legend_string = 'ITKrM';
                            line_style = 'k-x';
                    end
                    
                    color_1 = cmap(1,:);
                    color_2 = cmap(4,:);
                    color_3 = cmap(8,:);
                    color_4 = cmap(16,:);
                    
                    if i_embedding_type == 4
                        embedding_type_str = '';
                        [~, percent_recovered_atoms_vec, ...
                            ~, ~, scalability_dimensions, ...
                            scalability_average_time_per_iter] = ...
                            ictkm_simulation_gather_results(...
                            d_intrinsic_dimension, dico_type_str, ...
                            signal_type_str, embedding_type_str, ...
                            simulation_num);
                        
                        I = find(percent_recovered_atoms_vec > recovery_threshold);
                        num_iter_to_reach_threshold = I(1);
                        
                        % Linear fit the data
                        %                         p = polyfit(scalability_dimensions',...
                        %                             num_iter_to_reach_threshold*scalability_average_time_per_iter,1);
                        %
                        semilogy(scalability_dimensions, ...
                            num_iter_to_reach_threshold*scalability_average_time_per_iter,...
                            line_style, 'MarkerSize', 6);
                        %
                        %                         hold on;
                        %
                        %                         f = polyval(p,scalability_dimensions);
                        %                         plot(scalability_dimensions,f,'-','color',[0,0,0]+0.5)
                        %
                        %                         hold on;
                        %                         index_text_x_axis_description = ...
                        %                             ceil(length(scalability_dimensions)*.75);
                        %
                        %
                        %                         text(scalability_dimensions(index_text_x_axis_description),...
                        %                             polyval(p,scalability_dimensions(index_text_x_axis_description)),...
                        %                             [ '\alpha = ' num2str( p(1), '%1.2f' ) ], ...
                        %                             'color',[0,0,0]+0.5);
                        
                        disp(legend_string);
                        disp(num_iter_to_reach_threshold*scalability_average_time_per_iter);
                        
                        h = legend();
                        
                        if isempty(h)
                            h = legend(legend_string, 'Location', 'eastoutside');
                        else
                            newleg = h.String;
                            newleg{end+1} = legend_string; %#ok<AGROW>
                            h = legend(newleg, 'Location', 'eastoutside');
                        end
                    else
                        [dim_reduction_vector, ~, ...
                            percent_recovered_atoms_mat, ~, ...
                            scalability_dimensions, ...
                            scalability_average_time_per_iter_mat] = ...
                            ictkm_simulation_gather_results(...
                            d_intrinsic_dimension, dico_type_str, ...
                            signal_type_str, embedding_type_str, ...
                            simulation_num);
                        
                        
                        %----------------------------------------------
                        % Find suitable indices in dim_reduction_vector
                        % for showing the results
                        %----------------------------------------------
                        
                        num_dim_reduction = 2;
                        if simulation_num == 1
                            idx_min = 1;
                            idx_mid = 2;
                            idx_max = -1;
                        elseif simulation_num == 2
                            
                            idx_min = 1;
                            idx_mid = 4;
                            idx_max = -1;
                        end
                        
                        num_iter_to_reach_threshold_vec = ...
                            zeros(num_dim_reduction, 1);
                        
                        percent_recovered_atoms_vec = ...
                            percent_recovered_atoms_mat(idx_min, :);
                        I = find(percent_recovered_atoms_vec > ...
                            recovery_threshold);
                        num_iter_to_reach_threshold_vec(1) = I(1);
                        
                        percent_recovered_atoms_vec = ...
                            percent_recovered_atoms_mat(idx_mid, :);
                        I = find(percent_recovered_atoms_vec > ...
                            recovery_threshold);
                        num_iter_to_reach_threshold_vec(2) = I(1);
                        
                        if num_dim_reduction > 2
                            percent_recovered_atoms_vec = ...
                                percent_recovered_atoms_mat(idx_max, :);
                            I = find(percent_recovered_atoms_vec > ...
                                recovery_threshold);
                            num_iter_to_reach_threshold_vec(3) = I(1);
                        end
                        
                        legend_string_copy = legend_string;
                        for i_dim_reduction=1:num_dim_reduction
                            switch i_dim_reduction
                                case 1
                                    line_style = line_style_1;
                                    marker = marker_1;
                                    color = color_1;
                                    idx = idx_min;
                                    legend_string1 = ...
                                        [sprintf('%4.1f',1/dim_reduction_vector(idx)) ':1'];
                                    
                                    num_iter_to_reach_threshold = ...
                                        num_iter_to_reach_threshold_vec(1);
                                    
                                    scalability_average_time_per_iter = ...
                                        scalability_average_time_per_iter_mat(:,1);
                                    
                                    legend_string = [legend_string legend_string1]; %#ok<AGROW>
                                    
                                    disp(legend_string);
                                    disp(num_iter_to_reach_threshold*scalability_average_time_per_iter);
                                case 2
                                    line_style = line_style_2;
                                    marker = marker_2;
                                    color = color_2;
                                    idx = idx_mid;
                                    legend_string2 = ...
                                        [sprintf('%4.1f',1/dim_reduction_vector(idx)) ':1'];
                                    
                                    num_iter_to_reach_threshold = ...
                                        num_iter_to_reach_threshold_vec(2);
                                    
                                    scalability_average_time_per_iter = ...
                                        scalability_average_time_per_iter_mat(:,2);
                                    
                                    legend_string = [legend_string legend_string2]; %#ok<AGROW>
                                    
                                    disp(legend_string);
                                    disp(num_iter_to_reach_threshold*scalability_average_time_per_iter);
                                case 3
                                    if idx_max == -1
                                        continue;
                                    end
                                    
                                    line_style = line_style_4;
                                    color = color_4;
                                    marker = marker_4;
                                    idx = idx_max;
                                    legend_string4 = ...
                                        [sprintf('%4.1f',1/dim_reduction_vector(idx)) ':1'];
                                    
                                    num_iter_to_reach_threshold = ...
                                        num_iter_to_reach_threshold_vec(3);
                                    
                                    scalability_average_time_per_iter = ...
                                        scalability_average_time_per_iter_mat(:,3);
                                    
                                    legend_string = [legend_string legend_string4]; %#ok<AGROW>
                                    
                                    disp(legend_string);
                                    disp(num_iter_to_reach_threshold*scalability_average_time_per_iter);
                            end
                            
                            semilogx(scalability_dimensions, ...
                                scalability_average_time_per_iter*...
                                num_iter_to_reach_threshold, ...
                                'Color', color, 'LineStyle', line_style, ...
                                'Marker', marker, ...
                                'MarkerSize', 6);
                            hold on;
                            
                            if i_dim_reduction == 2
                                % Linear fit the data
                                %                                 p = polyfit(scalability_dimensions',...
                                %                                     num_iter_to_reach_threshold*scalability_average_time_per_iter,1);
                                %
                                %                                 f = polyval(p,scalability_dimensions);
                                %                                 plot(scalability_dimensions,f,'-','color',color_3)
                                %
                                %                                 hold on;
                                %                                 index_text_x_axis_description = ...
                                %                                     ceil(length(scalability_dimensions)*.75);
                                %
                                %                                 text(scalability_dimensions(index_text_x_axis_description),...
                                %                                     polyval(p,scalability_dimensions(index_text_x_axis_description)),...
                                %                                     [ '\alpha = ' num2str( p(1), '%1.2f' ) ], ...
                                %                                     'color',color_3);
                            end
                            
                            h = legend();
                            
                            if isempty(h)
                                h = legend(legend_string, 'Location', 'eastoutside');
                            else
                                newleg = h.String;
                                newleg{end+1} = legend_string; %#ok<AGROW>
                                h = legend(newleg, 'Location', 'eastoutside');
                            end
                            
                            legend_string = legend_string_copy;
                        end
                    end
                end
                
                %set(gca,'XLim', [0 100]);
                %set(gca,'YLim', [1/log(eps) (100+eps)]);
                %set(gca,'yscale','log');
                
                box off;
                %grid on;
                legend boxoff;
                axis tight;
                %h.Title.String = ['ambient dimension: ' ...
                %    addvilgole2( d_vector(i_dim) ) ];
                
                xlabel('ambient dimension');
                ylabel('cpu time (s)');
                
                set(gca,'XTickLabelMode','manual')
                
                tikz_filename_description = 'scalability';
                
                if saveFigToTikz
                    addpath('figs/tikz/');
                    
                    matlab2tikz(['figs/tikz/simulation_' ...
                        num2str(simulation_num) ...
                        '_' tikz_filename_description '.tikz'], ...
                        'height','\figureheight',...
                        'width','\figurewidth', ...
                        'extraaxisoptions','legend style={font=\tiny}');
                end
                
            end
        end
    end

    function show_convergence_speed_unrecovered_atoms(d_vector, ...
            recovery_threshold, simulation_num, saveFigToTikz, speedMetric)
        num_embedding_types=4;
        max_percent_recovery=0;
        
        %% Iterate over dictionary types
        for i_dico_type=1:2
            dico_type_str = [];
            if i_dico_type == 1
                dico_type_str = 'Random'; %#ok<NASGU>
                continue;
            elseif i_dico_type == 2
                dico_type_str = 'Dirac_DCT';
            end
            
            %% Iterate over signal types
            for i_signal_type=1:2
                signal_type_str = [];
                if i_signal_type == 1
                    signal_type_str = 'noiseless'; %#ok<NASGU>
                    continue;
                elseif i_signal_type == 2
                    signal_type_str = 'noisy';
                end
                
                %% Iterate over dimension vector
                for i_dim=1:length(d_vector)
                    figure;
                    for i_embedding_type=1:num_embedding_types
                        switch i_embedding_type
                            case 1
                                embedding_type_str = 'PartialFourier';
                                legend_string = 'IcTKM-DFT, ';
                                cmap = colormap(summer);
                            case 2
                                embedding_type_str = 'PartialDCT';
                                legend_string = 'IcTKM-DCT, ';
                                cmap = colormap(winter);
                            case 3
                                embedding_type_str = ...
                                    'PartialCirculant_Gaussian';
                                legend_string = 'IcTKM-CRT, ';
                                cmap = colormap(autumn);
                            case 4
                                legend_string = 'ITKrM';
                                line_style = 'k-x';
                        end
                        
                        color_1 = cmap(1,:);
                        color_2 = cmap(4,:);
                        color_3 = cmap(8,:);
                        color_4 = cmap(16,:);
                        
                        if i_embedding_type == 4
                            embedding_type_str = '';
                            [~, percent_recovered_atoms_vec, ...
                                ~, average_time_per_iter_vec, ...
                                ~] = ...
                                ictkm_simulation_gather_results(...
                                d_vector(i_dim), dico_type_str, ...
                                signal_type_str, embedding_type_str, ...
                                simulation_num);
                            
                            num_iter = length(percent_recovered_atoms_vec);
                            num_iter_vec = 1:num_iter;
                            
                            if speedMetric == 1
                                iter_spacing = 8;
                            elseif speedMetric == 2
                                iter_spacing = 6;
                            end
                            
                            xaxis_data = [];
                            if speedMetric == 1 % Number of iterations
                                xaxis_data = num_iter_vec(1:iter_spacing:num_iter);
                            elseif speedMetric == 2 % Average cpu time
                                xaxis_data = average_time_per_iter_vec*...
                                    num_iter_vec(1:iter_spacing:num_iter);
                            end
                            semilogy(xaxis_data,( 100-percent_recovered_atoms_vec(1:iter_spacing:num_iter) ),...
                                line_style, 'MarkerSize', 6);
                            
                            if max_percent_recovery < ...
                                    max(percent_recovered_atoms_vec)
                                max_percent_recovery = ...
                                    max(percent_recovered_atoms_vec);
                            end
                            
                            h = legend();
                            
                            if isempty(h)
                                h = legend(legend_string, 'Location', 'eastoutside');
                            else
                                newleg = h.String;
                                newleg{end+1} = legend_string; %#ok<AGROW>
                                h = legend(newleg, 'Location', 'eastoutside');
                            end
                        else
                            [dim_reduction_vector, ~, ...
                                percent_recovered_atoms_mat, ...
                                average_time_per_iter_vec, ...
                                ~] = ...
                                ictkm_simulation_gather_results(...
                                d_vector(i_dim), dico_type_str, ...
                                signal_type_str, embedding_type_str, ...
                                simulation_num);
                            
                            
                            %----------------------------------------------
                            % Find suitable indices in dim_reduction_vector
                            % for showing the results
                            %----------------------------------------------
                            % Automatically
                            %----------------------------------------------
                            %                             [I,~] = ind2sub( size(percent_recovered_atoms_mat), ...
                            %                                 find(percent_recovered_atoms_mat > recovery_threshold) );
                            
                            %                             idx_min = 1;
                            %                             idx_max = max(I);
                            %                             if isempty(idx_max)
                            %                                 idx_max = 2;
                            %                             end
                            %                             spacing=(idx_max-idx_min)/2;
                            %                             idx_mid = ceil(idx_min+spacing);
                            %----------------------------------------------
                            % Manually
                            %----------------------------------------------
                            idx_min = 1;
                            if simulation_num == 1
                                switch i_dim
                                    case 1
                                        idx_mid = 3;
                                        if i_embedding_type == 1
                                            idx_max = 6;
                                        else
                                            idx_max = -1;
                                        end
                                    case 2
                                        idx_mid = 3;
                                        if i_embedding_type == 1
                                            idx_max = 6;
                                        else
                                            idx_max = -1;
                                        end
                                    case 3
                                        idx_mid = 2;
                                        if i_embedding_type == 1
                                            idx_max = 4;
                                        else
                                            idx_max = -1;
                                        end
                                end
                            elseif simulation_num == 2
                                idx_mid = 4;
                                idx_max = 6;
                            end
                            %----------------------------------------------
                            
                            if max_percent_recovery < ...
                                    max(percent_recovered_atoms_mat(:))
                                max_percent_recovery = ...
                                    max(percent_recovered_atoms_mat(:));
                            end
                            
                            legend_string_copy = legend_string;
                            for i_dim_reduction=1:3
                                switch i_dim_reduction
                                    case 1
                                        line_style = line_style_1;
                                        marker = marker_1;
                                        color = color_1;
                                        idx = idx_min;
                                        legend_string1 = ...
                                            [sprintf('%4.1f',1/dim_reduction_vector(idx)) ':1'];
                                        
                                        legend_string = [legend_string legend_string1]; %#ok<AGROW>
                                    case 2
                                        line_style = line_style_2;
                                        marker = marker_2;
                                        color = color_2;
                                        idx = idx_mid;
                                        legend_string2 = ...
                                            [sprintf('%4.1f',1/dim_reduction_vector(idx)) ':1'];
                                        
                                        legend_string = [legend_string legend_string2]; %#ok<AGROW>
                                    case 3
                                        if idx_max == -1
                                            continue;
                                        end
                                        
                                        line_style = line_style_4;
                                        color = color_4;
                                        marker = marker_4;
                                        idx = idx_max;
                                        
                                        
                                        legend_string4 = ...
                                            [sprintf('%4.1f',1/dim_reduction_vector(idx)) ':1'];
                                        
                                        legend_string = [legend_string legend_string4]; %#ok<AGROW>
                                end
                                
                                num_iter = size(percent_recovered_atoms_mat,2);
                                num_iter_vec = 1:num_iter;
                                
                                if speedMetric == 1
                                    iter_spacing = 8;
                                elseif speedMetric == 2
                                    iter_spacing = 6;
                                end
                                
                                xaxis_data = [];
                                if speedMetric == 1 % Number of iterations
                                    xaxis_data = num_iter_vec(1:iter_spacing:num_iter);
                                elseif speedMetric == 2 % Average cpu time
                                    xaxis_data = average_time_per_iter_vec(idx)*...
                                        num_iter_vec(1:iter_spacing:num_iter);
                                end
                                
                                semilogy(xaxis_data,( 100-percent_recovered_atoms_mat(idx,...
                                    1:iter_spacing:num_iter) ), ...
                                    'Color', color, 'LineStyle', line_style, ...
                                    'Marker', marker, ...
                                    'MarkerSize', 6);
                                hold on;
                                
                                h = legend();
                                
                                if isempty(h)
                                    h = legend(legend_string, 'Location', 'eastoutside');
                                else
                                    newleg = h.String;
                                    newleg{end+1} = legend_string; %#ok<AGROW>
                                    h = legend(newleg, 'Location', 'eastoutside');
                                end
                                
                                legend_string = legend_string_copy;
                            end
                        end
                    end
                    
                    %set(gca,'XLim', [0 100]);
                    %set(gca,'YLim', [1/log(eps) (100+eps)]);
                    %set(gca,'yscale','log');
                    
                    box off;
                    %grid on;
                    legend boxoff;
                    axis tight;
                    h.Title.String = ['ambient dimension: ' ...
                        addvilgole2( d_vector(i_dim) ) ];
                    
                    if speedMetric == 1
                        if simulation_num == 2 && i_dim == 2
                            % Limit y-axis manually
                            ylim([6.2 100]);
                        end
                        
                        plot([0 num_iter_vec(end)], [100-recovery_threshold...
                            100-recovery_threshold], ...
                            'y-', 'LineWidth', 1);
                    elseif speedMetric == 2
                        x_lim_cputime = [];
                        
                        if simulation_num == 1
                            switch i_dim
                                case 1
                                    x_lim_cputime = [20 2001];
                                case 2
                                    x_lim_cputime = [109 11280];
                                case 3
                                    x_lim_cputime = [542 58750];
                            end
                        elseif simulation_num == 2
                            switch i_dim
                                case 1
                                    x_lim_cputime = [64 6752];
                                case 2
                                    x_lim_cputime = [241 26430];
                                case 3
                                    x_lim_cputime = [1182 125510];
                            end
                        end
                        
                        xlim(x_lim_cputime);
                        plot(x_lim_cputime, [100-recovery_threshold...
                            100-recovery_threshold], 'y-', 'LineWidth', 1);
                    end
                    
                    tikz_filename_description = [];
                    if speedMetric == 1
                        xlabel('iteration');
                        tikz_filename_description = 'numiter';
                    elseif speedMetric == 2 % Average cpu time
                        xlabel('cpu time (s)');
                        tikz_filename_description = 'cputime';
                    end
                    ylabel('unrecovered atoms (%)');
                    
                    if saveFigToTikz
                        addpath('figs/tikz/');
                        
                        matlab2tikz(['figs/tikz/simulation_' ...
                            num2str(simulation_num) ...
                            '_' tikz_filename_description '_', ...
                            '_d_' num2str(d_vector(i_dim)) '.tikz'], ...
                            'height','\figureheight',...
                            'width','\figurewidth', ...
                            'extraaxisoptions','legend style={font=\tiny}');
                    end
                end
                
            end
        end
    end

    function strnumnew=addvilgole2(num)
        if isnumeric(num)==1
            strnum=num2str(num);
            strnum2=regexprep(fliplr(strnum),' ','');
        else
            if ischar(num)==1
                if sum(ismember(num,','))==0
                    strnum2=regexprep(fliplr(num),' ','');
                end
            end
        end
        if isempty(str2num(strnum2))==0
            strnum3=[];
            for i=1:size(strnum2,2)
                iv=logical(abs(double(logical(i-fix(i/3)*3))-1));
                if iv
                    if i~=size(strnum2,2)
                        strv=[strnum2(1,i) ','];
                    else
                        strv=strnum2(1,i);
                    end
                else
                    strv=strnum2(1,i);
                end
                strnum3=[strnum3 strv];
            end
            strnumnew=fliplr(strnum3);
        else
            strnumnew=num;
        end
    end   
end