function opts = ictkm_set_defaults(opts, dataObj)
% -------------------------------------------------------------------------
% Set default values for IcTKM's option structure.
% -------------------------------------------------------------------------
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compressed Dictionary Learning Toolbox
% Copyright (C) Flavio Teixeira 2018
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor,
% Boston, MA  02110-1301, USA.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%------------------------------------------------------------------
%-------------------------- Set defaults --------------------------
%------------------------------------------------------------------
numIter_min = 1e0;
numIter_default = 1e2;
numIter_max = 1e5;
%------------------------------------------------------------------
setOpts( 'numIter', numIter_default, ...
    numIter_min, numIter_max );
setOpts('noSketching', false);
setOpts('nonNegative', false);
%------------------------------------------------------------------
setOpts('runMode', 'sequential');
%------------------------------------------------------------------
setOpts('verbose', true);
%------------------------------------------------------------------
mCls=metaclass(dataObj);
if isempty(mCls.SuperclassList)
    error('Invalid data object type.')
end
if ~strcmp(mCls.SuperclassList(1).Name, 'ictkm_data')
    error('Data object does not inherit from IcTKMData abstract class');
end

%------------------------------------------------------------------
%---- internal routine for setting defaults
%------------------------------------------------------------------
    function [var,userSet] = setOpts(field,default,mn,mx)
        var = default;
        % has the option already been set?
        if ~isfield(opts,field)
            % see if there is a capitalization problem:
            names = fieldnames(opts);
            for i = 1:length(names)
                if strcmpi(names{i},field)
                    opts.(field) = opts.(names{i});
                    opts = rmfield(opts,names{i});
                    break;
                end
            end
        end
        if isfield(opts,field) && ~isempty(opts.(field))
            var = opts.(field);  % override the default
            userSet = true;
        else
            userSet = false;
        end
        % perform error checking, if desired
        if nargin >= 3 && ~isempty(mn)
            if var < mn
                printf('Variable %s is %f, should be at least %f\n',...
                    field,var,mn); error('variable out-of-bounds');
            end
        end
        if nargin >= 4 && ~isempty(mx)
            if var > mx
                printf('Variable %s is %f, should be at least %f\n',...
                    field,var,mn); error('variable out-of-bounds');
            end
        end
        if strcmpi('lParameter',field)
            if mod(var,1)~=0
                printf('Variable %s is %f, must be an integer \n',...
                    field,var); error('variable must be an integer');
            end
        end
        opts.(field) = var;
    end
end