function ictkm_update_display(opts, dataObj, results)
% -------------------------------------------------------------------------
% Update IcTKM's progress status on the console.
% -------------------------------------------------------------------------
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compressed Dictionary Learning Toolbox
% Copyright (C) Flavio Teixeira 2018
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor,
% Boston, MA  02110-1301, USA.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

printHeader(opts);
printOpts(opts, dataObj);
printStats(opts, dataObj, results);

    function printHeader(opts)
        if (opts.verbose)
            clc;
            
            fprintf('+------------------------------------');
            fprintf('------------------------------------+');
            fprintf('\n');
            
            disp([sprintf('\t') 'Iterative Compressed Thresholding and K-Means Algorithm']);
            
            fprintf('+------------------------------------');
            fprintf('------------------------------------+');
            fprintf('\n');
        end
    end

    function printOpts(opts, dataObj)
        
        if (opts.verbose)
            fprintf('\n\t');
            fprintf('+-------------------------------------------------------+');
            fprintf('\n');
            
            fprintf('\t');
            fprintf('|-----------------------Options-------------------------|');
            fprintf('\n\t');
            fprintf('+-------------------------------------------------------+');
            fprintf('\n');                      
            
            fprintf('\t');
            disp(['Problem size: ' sprintf('\t\t\t') '(d,K,N)=' '(' num2str(opts.d) ...
                ',' num2str(opts.K) ',' num2str(dataObj.N) ')' ]);
            
            if isa(dataObj, 'IcTKMSyntheticData')
                fprintf('\t\t');
                disp(['Synthetic data: ' sprintf('\t') '(S,b,rho)=' '(' num2str(dataObj.S) ...
                    ',' num2str(dataObj.b) ',' num2str(dataObj.rho) ')' ]);
            end
                        
            if ~opts.noSketching
                fprintf('\t');
                disp([opts.FJLTtype ' Embed.:' ...
                    sprintf('\t\t')  'm=' num2str(opts.m) ...
                    '(comp.ratio=' num2str(ceil(opts.d/opts.m)) ':1)' ]);
            end
        end
        
    end


    function printStats(opts, dataObj, results)
        
        if (opts.verbose)
            fprintf('\n\t');
            fprintf('+-------------------------------------------------------+');
            fprintf('\n');
            
            fprintf('\t');
            fprintf('|-------------------------Stats-------------------------|');
            fprintf('\n\t');
            fprintf('+-------------------------------------------------------+');
            fprintf('\n');
            
            if isa(dataObj, 'IcTKMSyntheticData') && results.iteration > 1
                fprintf('\t\t');
                disp(['Recovery error: ' sprintf('\t') ...
                    num2str(results.approx_error( results.iteration - 1 ) ) ]);
                
                fprintf('\t\t');
                disp(['Atoms recovered: ' sprintf('\t') ...
                    num2str( results.recovery_percent(results.iteration - 1) ) '%' ]);
            end
            
            fprintf('\t\t');
            disp(['Total time: ' sprintf('\t\t') ...
                num2str(results.runTime) ' sec.' ]);
            
            fprintf('\t\t');
            pb = cmd_line_progress_bar('Total progress: ');
            pb.print(results.iteration, opts.numIter);
            fprintf('\n');
            
            fprintf('\t\t');
            disp(['Avg. time per iter.: ' sprintf('\t') ...
                num2str(results.avgTimePerIter) ' sec.' ]);
        end
        
    end

end