function init_gpu()
% -------------------------------------------------------------------------
% Initialize an available CUDA GPU.
% -------------------------------------------------------------------------
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compressed Dictionary Learning Toolbox
% Copyright (C) Flavio Teixeira 2018
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor,
% Boston, MA  02110-1301, USA.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Can change this on multi-GPU setups
gpuIdx = 1;
% Query device without selecting it
if parallel.gpu.GPUDevice.getDevice(gpuIdx).DeviceSelected
    % Retrieve selected device
    parallel.gpu.GPUDevice.getDevice(gpuIdx);
else
    % Select GPU device for use
    gpuDevice(gpuIdx);
    % dummy - trick matlab to initialize gpu memory pool
    gpuArray( zeros(1,1) );
    % This prevents MATLAB from using the GPU memory pool,
    % thus avoiding memory hogging and allowing us to
    % learn bigger dictionaries.
    feature('GpuAllocPoolSizeKb', 0);    
end

end