function init_parallel_toolbox(boostNumWorkers)
% -------------------------------------------------------------------------
% Initialize MATLAB's parallel toolbox.
% -------------------------------------------------------------------------
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compressed Dictionary Learning Toolbox
% Copyright (C) Flavio Teixeira 2018
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor,
% Boston, MA  02110-1301, USA.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

targetNumWorkers = feature('numCores')/8;
if boostNumWorkers
    targetNumWorkers = targetNumWorkers*2;
end

poolobj = gcp('nocreate');
c = parcluster('local');
if ~isempty(poolobj) && ~isdeployed
    if c.NumWorkers ~= targetNumWorkers
        delete(poolobj);
        poolobj = [];
    end
end

if isempty(poolobj)
    if isdeployed
        % -----------------------------------------------------------------
        % Generate parallel pool data directory, needed when running
        % multiple  matlab pool instances on the same machine.
        % -----------------------------------------------------------------
        clk = clock();
        directory_name = ['tmp_' num2str(clk(1)) '_' num2str(clk(2)) '_'...
            num2str(clk(3)) '_' num2str(clk(4)) '_' num2str(clk(5)) ...
            '_' num2str(clk(6))];
        mkdir(directory_name);                  % This should be an unique
        % folder so let's create it
        % first
        c.JobStorageLocation = directory_name;
    end
    
    c.NumWorkers = targetNumWorkers;
    parpool(c, c.NumWorkers);
end

end
