% NAME
%   spPitchCepstrum - Pitch Estimation via Cepstral Method
% SYNOPSIS
%   [f0] = spPitchCepstrum(c, fs)
% DESCRIPTION
%   Estimate pitch frequencies via Cepstral method
% INPUTS
%   c        (vector) of size Nx1 which contains cepstrum coefficients. 
%             Use spCepstrum.m
%   fs       (scalar) the sampling frequency of the original signal
% OUTPUTS
%   f0       (scalar) the estimated pitch
% AUTHOR
%   Naotoshi Seo, April 2008
% See also
%   spCepstrum.m
function [f0] = spPitchCepstrum(c, fs, f_min, f_max)
 % search for maximum  between (1/f_max) and (1/f_min)
 ms_min=floor(fs/f_max);
 ms_max=floor(fs/f_min); 
 [~,idx]=max(abs(c(ms_min:ms_max)));
 f0 = fs/(ms_min+idx-1);
end