% NAME
%   spPitchCorr - Pitch Estimation via Auto-correlation Method
% SYNOPSIS
%   [f0] = spPitchCorr(r, fs)
% DESCRIPTION
%   Estimate pitch frequencies via the Auto-correlation method
% INPUTS
%   r        (vector) of size (maxlag*2+1)x1 which contains Corr coefficients. 
%             Use spCorr.m
%   fs       (scalar) the sampling frequency of the original signal
% OUTPUTS
%   f0       (scalar) the estimated pitch
% AUTHOR
%   Naotoshi Seo, April 2008
% See also
%   spCorr.m
function [f0] = spPitchCorr(r, fs, f_min, f_max)
 % search for maximum  between (1/f_max) and (1/f_min)
 ms_min=floor(fs/f_max);
 ms_max=floor(fs/f_min); 
 % half is just mirror for real signal
 r = r(floor(length(r)/2):end);
 [~,idx]=max(r(ms_min:ms_max));
 f0 = fs/(ms_min+idx-1);
end